<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="600px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="150px" >
        <el-form-item v-if="state.isAdmin" label="企业：" prop="companyId">
          <el-select
              v-model="state.form.companyName"
              filterable
              remote
              @change="selectValue"
              reserve-keyword
              placeholder="请输入企业名称"
              remote-show-suffix
              :remote-method="getCompanyList"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="序号:" prop="num">
          <el-input v-model.trim="state.form.num" :disabled="state.title =='查看'" placeholder="序号"></el-input>
        </el-form-item>
        <el-form-item label="上级分支:" prop="parentId">
          <el-tree-select
              v-model="state.form.parentId"
              :data="state.menuOptions"
              :props="{ value: 'id', label: 'label', children: 'children' }"
              value-key="id"
              placeholder="上级分支"
              check-strictly
              style="width: 100%"
          />
        </el-form-item>
        <el-form-item label="目录名称:" prop="name">
          <el-input v-model.trim="state.form.name" :disabled="state.title =='查看'" placeholder="目录名称"></el-input>
        </el-form-item>
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import {ElMessage} from "element-plus";
import {addUser, editUser, getUserById, resetPwd} from "@/api/onlineEducation/user"
import {Base64} from "js-base64"
import {getCompany} from "@/api/onlineEducation/company";
import {addIndustryTemp, updateIndustryTemp, updateInfoPlatforms} from "@/api/staffManage/staff";
import {getToken} from "@/utils/auth";
import {delPic} from "@/api/onlineEducation/banner";
import {listMenu} from "@/api/system/menu";

const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref()
const state = reactive({
  title: '',
  form: {
    id: null,
    name: '',
    num:'',
    companyId: null,
    parentId: null
  },
  formRules:{
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    name: [{ required: true, message: '请输入目录名称', trigger: 'blur' }],
    num: [{ required: true, message: '请输入序号', trigger: 'blur' }],
    parentId:[{ required: true, message: '请选择上级分支', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  menuOptions: []
})
onMounted(() => {

});

const openDialog = async (type, value,companyId, isAdmin,flag) => {
  state.isAdmin = isAdmin
  if(isAdmin){
    await getCompanyList()
    await getTreeselect()
  }
  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看'
  state.form.companyId = companyId
  if(state.title == '新增' && flag == 2){
    state.form.parentId = value.id
  }else if(state.title == '新增' && flag == 1){
    state.form.parentId = 0
  }
  if(state.title == '编辑'||state.title == '查看'){
    Object.keys(state.form).forEach(key => {
      if (key in value) {
        state.form[key] = value[key]
      }
    })
  }
  dialogVisible.value = true
}


const onSubmit = async () => {
  const valid = await superRef.value.validate();
  console.log('state.form',state.form)
  if(valid){
    if(state.title == '新增'){
      const {id,...data} = state.form
      const res = await addIndustryTemp(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const res = await updateIndustryTemp(state.form)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}
const getTreeselect =async ()=> {
  // state.menuOptions = [];
  // const res = await addIndustryTemp()
  // if(res.code == 200){
  //   const menu = { id: 0, name: "1范围", children: [] };
  //   menu.children = response.data
  //   state.menuOptions.push(menu);
  // }else{
  //   ElMessage.warning(res.message)
  // }
  state.menuOptions = [];
    const menu = { id: 0, label: "1范围", children: [] };
    menu.children = [
      {
        id: 1,
        label: '1.1规范范围管理',
        children: [
          {
            id: 2,
            label: 'Level three 1-1-1',
            children: [
              {
                id: 3,
                label: 'Level three 1-1-1',
                children: [
                  {
                    id: 4,
                    label: 'Level three 1-1-1',
                  },
                ],
              },
            ],
          },
        ],
      },
      {
        id: 5,
        label: '1.2收集需求',
      },
      {
        id: 6,
        label: '1.3定义范围',
      },
    ]
    state.menuOptions.push(menu);

}

const handleClose = () => {
  state.form = {
    id: null,
    name: '',
    num:'',
    companyId: null,
    parentId: null
  }
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}
const selectValue = (val) => {
  state.companyList.forEach(item => {
    if(item.name === val){
      state.form.companyId = item.id
    }
  })
}

const getCompanyList = async (val)=>{
  if(val){
    const queryParams = {
      name: val
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      state.companyList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }else {
    const queryParams = {
      pageSize: 10,
      pageNum: 1,
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      state.companyList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
